@@ -845,13 +845,19 @@ xchat_printf (xchat_plugin *ph, const char *format, ...)
 void
 xchat_command (xchat_plugin *ph, const char *command)
 {
+	char *conv;
+	int len = -1;
+
 	if (!is_session (ph->context))
 	{
 		DEBUG(PrintTextf(0, "%s\txchat_command called without a valid context.\n", ph->name));
 		return;
 	}
 
+	/* scripts/plugins continue to send non-UTF8... *sigh* */
+	conv = text_validate ((char **)&command, &len);
 	handle_command (ph->context, (char *)command, FALSE);
+	g_free (conv);
 }
 
 void
@@ -1174,12 +1180,12 @@ xchat_list_fields (xchat_plugin *ph, const char *name)
 	static const char * const dcc_fields[] =
 	{
 		"iaddress32","icps",		"sdestfile","sfile",		"snick",	"iport",
-		"ipos",		"iresume",	"isize",		"istatus", 	"itype",		NULL
+		"ipos", "iresume", "isize", "isizehigh", "istatus", "itype", NULL
 	};
 	static const char * const channels_fields[] =
 	{
-		"schannel",	"schantypes", "pcontext", "iflags", "iid", "imaxmodes",
-		"snetwork", "snickmodes", "snickprefixes", "sserver", "itype", "iusers",
+		"schannel",	"schantypes", "pcontext", "iflags", "iid", "ilag", "imaxmodes",
+		"snetwork", "snickmodes", "snickprefixes", "iqueue", "sserver", "itype", "iusers",
 		NULL
 	};
 	static const char * const ignore_fields[] =
@@ -1188,7 +1194,7 @@ xchat_list_fields (xchat_plugin *ph, const char *name)
 	};
 	static const char * const notify_fields[] =
 	{
-		"iflags", "snick", "toff", "ton", "tseen", NULL
+		"iflags", "snetworks", "snick", "toff", "ton", "tseen", NULL
 	};
 	static const char * const users_fields[] =
 	{
@@ -1311,6 +1317,8 @@ xchat_list_str (xchat_plugin *ph, xchat_list *xlist, const char *name)
 	case LIST_NOTIFY:
 		switch (hash)
 		{
+		case 0x4e49ec05:	/* networks */
+			return ((struct notify *)data)->networks;
 		case 0x339763: /* nick */
 			return ((struct notify *)data)->name;
 		}
@@ -1362,7 +1370,9 @@ xchat_list_int (xchat_plugin *ph, xchat_list *xlist, const char *name)
 		case 0xc84dc82d: /* resume */
 			return ((struct DCC *)data)->resumable;
 		case 0x35e001: /* size */
-			return ((struct DCC *)data)->size;
+			return ((struct DCC *)data)->size & 0xffffffff;
+		case 0x3284d523: /* sizehigh */
+			return (((struct DCC *)data)->size >> 32) & 0xffffffff;
 		case 0xcacdcff2: /* status */
 			return ((struct DCC *)data)->dccstat;
 		case 0x368f3a: /* type */
@@ -1402,8 +1412,12 @@ xchat_list_int (xchat_plugin *ph, xchat_list *xlist, const char *name)
 			tmp <<= 1;
 			tmp |= ((struct session *)data)->server->connected;  /* 0 */
 			return tmp;
+		case 0x1a192: /* lag */
+			return ((struct session *)data)->server->lag;
 		case 0x1916144c: /* maxmodes */
 			return ((struct session *)data)->server->modes_per_line;
+		case 0x66f1911: /* queue */
+			return ((struct session *)data)->server->sendq_len;
 		case 0x368f3a:	/* type */
 			return ((struct session *)data)->type;
 		case 0x6a68e08: /* users */
