@@ -26,11 +26,6 @@
 #include <stdarg.h>
 
 #include "xchat.h"
-
-#ifdef WIN32
-#include "inet.h"	/* for gethostname() */
-#endif
-
 #include "ctcp.h"
 #include "fe.h"
 #include "ignore.h"
@@ -48,20 +43,13 @@
 static void
 irc_login (server *serv, char *user, char *realname)
 {
-	char hostname[128];
-
 	if (serv->password[0])
 		tcp_sendf (serv, "PASS %s\r\n", serv->password);
 
-	gethostname (hostname, sizeof (hostname) - 1);
-	hostname[sizeof (hostname) - 1] = 0;
-	if (hostname[0] == 0)
-		strcpy (hostname, "0");
-
 	tcp_sendf (serv,
 				  "NICK %s\r\n"
 				  "USER %s %s %s :%s\r\n",
-				  serv->nick, user, hostname, serv->servername, realname);
+				  serv->nick, user, user, serv->servername, realname);
 }
 
 static void
@@ -354,7 +342,8 @@ process_numeric (session * sess, int n,
 		}
 
 		/* use /NICKSERV */
-		if (strcasecmp (word[7], "DALnet") == 0)
+		if (strcasecmp (word[7], "DALnet") == 0 ||
+			 strcasecmp (word[7], "BRASnet") == 0)
 			serv->nickservtype = 1;
 
 		/* use /NS */
@@ -639,7 +628,10 @@ process_numeric (session * sess, int n,
 	case 349:	/* end of exemption list */
 		sess = find_channel (serv, word[4]);
 		if (!sess)
+		{
 			sess = serv->front_session;
+			goto def;
+		}
 		if (!fe_is_banwindow (sess))
 			goto def;
 		fe_ban_list_end (sess, TRUE);
@@ -662,12 +654,21 @@ process_numeric (session * sess, int n,
 	case 368:
 		sess = find_channel (serv, word[4]);
 		if (!sess)
+		{
 			sess = serv->front_session;
+			goto def;
+		}
 		if (!fe_is_banwindow (sess))
 			goto def;
 		fe_ban_list_end (sess, FALSE);
 		break;
 
+	case 369:	/* WHOWAS end */
+	case 406:	/* WHOWAS error */
+		EMIT_SIGNAL (XP_TE_SERVTEXT, whois_sess, text, word[1], NULL, NULL, 0);
+		serv->inside_whois = 0;
+		break;
+
 	case 372:	/* motd text */
 	case 375:	/* motd start */
 		if (!prefs.skipmotd || serv->motd_skipped)
@@ -680,7 +681,8 @@ process_numeric (session * sess, int n,
 		inbound_login_end (sess, text);
 		break;
 
-	case 433:
+	case 433:	/* nickname in use */
+	case 432:	/* erroneous nickname */
 		if (serv->end_of_motd)
 			goto def;
 		inbound_next_nick (sess,  word[4]);
@@ -923,7 +925,7 @@ process_named_msg (session *sess, char *type, char *word[], char *word_eol[])
 							flood_check (nick, ip, serv, sess, 0);
 						if (strncasecmp (text, "DCC ", 4) == 0)
 							/* redo this with handle_quotes TRUE */
-							process_data_init (word[1], word_eol[1], word, word_eol, TRUE);
+							process_data_init (word[1], word_eol[1], word, word_eol, TRUE, FALSE);
 						ctcp_handle (sess, to, nick, text, word, word_eol, id);
 					} else
 					{
@@ -1011,7 +1013,7 @@ irc_inline (server *serv, char *buf, int len)
 	if (buf[0] == ':')
 	{
 		/* split line into words and words_to_end_of_line */
-		process_data_init (pdibuf, buf, word, word_eol, FALSE);
+		process_data_init (pdibuf, buf, word, word_eol, FALSE, FALSE);
 
 		/* find a context for this message */
 		if (is_channel (serv, word[3]))
@@ -1033,7 +1035,7 @@ irc_inline (server *serv, char *buf, int len)
 
 	} else
 	{
-		process_data_init (pdibuf, buf, word, word_eol, FALSE);
+		process_data_init (pdibuf, buf, word, word_eol, FALSE, FALSE);
 		word[0] = type = word[1];
 		if (plugin_emit_server (sess, type, word, word_eol))
 			goto xit;
