@@ -110,8 +110,13 @@ tcp_send_real (server *serv, char *buf, int len)
 		}
 	} else
 	{
-		locale = g_convert_with_fallback (buf, len, serv->encoding, "UTF-8",
-													 "?", 0, &loc_len, 0);
+		if (serv->using_irc)	/* using "IRC" encoding (CP1252/UTF-8 hybrid) */
+			/* if all chars fit inside CP1252, use that. Otherwise this
+			   returns NULL and we send UTF-8. */
+			locale = g_convert (buf, len, "CP1252", "UTF-8", 0, &loc_len, 0);
+		else
+			locale = g_convert_with_fallback (buf, len, serv->encoding, "UTF-8",
+														 "?", 0, &loc_len, 0);
 	}
 
 	if (locale)
@@ -292,8 +297,9 @@ server_inline (server *serv, char *line, int len)
 	char *utf_line_allocated = NULL;
 
 	/* Checks whether we're set to use UTF-8 charset */
-	if ((serv->encoding == NULL && prefs.utf8_locale) ||
-	    (serv->encoding != NULL &&
+	if (serv->using_irc ||				/* 1. using CP1252/UTF-8 Hybrid */
+		(serv->encoding == NULL && prefs.utf8_locale) || /* OR 2. using system default->UTF-8 */
+	    (serv->encoding != NULL &&				/* OR 3. explicitly set to UTF-8 */
 		 (strcasecmp (serv->encoding, "UTF8") == 0 ||
 		  strcasecmp (serv->encoding, "UTF-8") == 0)))
 	{
@@ -806,6 +812,13 @@ auto_reconnect (server *serv, int send_quit, int err)
 #endif
 		serv->reconnect_away = serv->is_away;
 
+	/* is this server in a reconnect delay? remove it! */
+	if (serv->recondelay_tag)
+	{
+		fe_timeout_remove (serv->recondelay_tag);
+		serv->recondelay_tag = 0;
+	}
+
 	serv->recondelay_tag = fe_timeout_add (del, timeout_auto_reconnect, serv);
 	fe_server_event (serv, FE_SE_RECONDELAY, del);
 }
@@ -1087,6 +1100,7 @@ server_disconnect (session * sess, int sendquit, int err)
 	server *serv = sess->server;
 	GSList *list;
 	char tbuf[64];
+	gboolean shutup = FALSE;
 
 	/* send our QUIT reason */
 	if (sendquit && serv->connected)
@@ -1106,6 +1120,8 @@ server_disconnect (session * sess, int sendquit, int err)
 		sprintf (tbuf, "%d", sess->server->childpid);
 		EMIT_SIGNAL (XP_TE_STOPCONNECT, sess, tbuf, NULL, NULL, NULL, 0);
 		return;
+	case 3:
+		shutup = TRUE;	/* won't print "disconnected" in channels */
 	}
 
 	server_flush_queue (serv);
@@ -1116,9 +1132,10 @@ server_disconnect (session * sess, int sendquit, int err)
 		sess = (struct session *) list->data;
 		if (sess->server == serv)
 		{
-			/* print "Disconnected" to each window using this server */
-			EMIT_SIGNAL (XP_TE_DISCON, sess, errorstring (err), NULL, NULL, NULL,
-							 0);
+			if (!shutup || sess->type == SESS_SERVER)
+				/* print "Disconnected" to each window using this server */
+				EMIT_SIGNAL (XP_TE_DISCON, sess, errorstring (err), NULL, NULL, NULL, 0);
+
 			if (!sess->channel[0] || sess->type == SESS_CHANNEL)
 				clear_channel (sess);
 		}
@@ -1534,7 +1551,10 @@ server_child (server * serv)
 	if (!serv->dont_use_proxy && (prefs.proxy_type == 5))
 		error = net_connect (ns_server, serv->proxy_sok4, serv->proxy_sok6, &psok);
 	else
+	{
 		error = net_connect (ns_server, serv->sok4, serv->sok6, &sok);
+		psok = sok;
+	}
 
 	if (error != 0)
 	{
@@ -1630,7 +1650,21 @@ server_connect (server *serv, char *hostname, int port, int no_login)
 	EMIT_SIGNAL (XP_TE_SERVERLOOKUP, sess, hostname, NULL, NULL, NULL, 0);
 
 	safe_strcpy (serv->servername, hostname, sizeof (serv->servername));
-	safe_strcpy (serv->hostname, hostname, sizeof (serv->hostname));
+	/* overlap illegal in strncpy */
+	if (hostname != serv->hostname)
+		safe_strcpy (serv->hostname, hostname, sizeof (serv->hostname));
+
+#ifdef USE_OPENSSL
+	if (serv->use_ssl)
+	{
+		char cert_file[256];
+
+		snprintf (cert_file, sizeof (cert_file), "%s/%s.pem",
+					 get_xdir_fs (), server_get_network (serv, TRUE));
+		if (SSL_CTX_use_certificate_file (ctx, cert_file, SSL_FILETYPE_PEM) == 1)
+			SSL_CTX_use_PrivateKey_file (ctx, cert_file, SSL_FILETYPE_PEM);
+	}
+#endif
 
 	server_set_defaults (serv);
 	serv->connecting = TRUE;
@@ -1672,9 +1706,7 @@ server_connect (server *serv, char *hostname, int port, int no_login)
 										(LPTHREAD_START_ROUTINE)server_child,
 										serv, 0, (DWORD *)&pid));
 #else
-#ifdef LOOKUPD
-	rand();	/* CL: net_resolve calls rand() when LOOKUPD is set, so prepare a different seed for each child. This method giver a bigger variation in seed values than calling srand(time(0)) in the child itself. */
-#endif
+	rand();	/* CL: net_resolve calls rand(), so prepare a different seed for each child. This method giver a bigger variation in seed values than calling srand(time(0)) in the child itself. */
 	switch (pid = fork ())
 	{
 	case -1:
@@ -1715,6 +1747,7 @@ server_set_encoding (server *serv, char *new_encoding)
 		/* can be left as NULL to indicate system encoding */
 		serv->encoding = NULL;
 		serv->using_cp1255 = FALSE;
+		serv->using_irc = FALSE;
 	}
 
 	if (new_encoding)
@@ -1726,10 +1759,12 @@ server_set_encoding (server *serv, char *new_encoding)
 		if (space)
 			space[0] = 0;
 
-		/* server_inline() uses this flag */
+		/* server_inline() uses these flags */
 		if (!strcasecmp (serv->encoding, "CP1255") ||
 			 !strcasecmp (serv->encoding, "WINDOWS-1255"))
 			serv->using_cp1255 = TRUE;
+		else if (!strcasecmp (serv->encoding, "IRC"))
+			serv->using_irc = TRUE;
 	}
 }
 
@@ -1781,7 +1816,7 @@ server_set_defaults (server *serv)
 	serv->nick_modes = strdup ("ohv");
 
 	serv->nickcount = 1;
-	serv->nickservtype = 0;
+	serv->nickservtype = 1;
 	serv->end_of_motd = FALSE;
 	serv->is_away = FALSE;
 	serv->supports_watch = FALSE;
