@@ -43,6 +43,13 @@ struct server_gui
 	GtkWidget *rawlog_window;
 	GtkWidget *rawlog_textlist;
 
+	/* join dialog */
+	GtkWidget *joind_win;
+	GtkWidget *joind_entry;
+	GtkWidget *joind_radio1;
+	GtkWidget *joind_radio2;
+	GtkWidget *joind_check;
+
 	/* chanlist variables */
 	GtkWidget *chanlist_wild;
 	GtkWidget *chanlist_window;
@@ -86,7 +93,7 @@ typedef struct restore_gui
 	GtkWidget *banlist_treeview;
 	GtkWidget *banlist_butRefresh;
 
-	GtkWidget *tab;		/* toggleButton */
+	void *tab;			/* (chan *) */
 
 	/* information stored when this tab isn't front-most */
 	void *user_model;	/* for filling the GtkTreeView */
@@ -98,9 +105,10 @@ typedef struct restore_gui
 	gfloat old_ul_value;	/* old userlist value (for adj) */
 	gfloat lag_value;	/* lag-o-meter */
 	char *lag_text;	/* lag-o-meter text */
+	char *lag_tip;		/* lag-o-meter tooltip */
 	gfloat queue_value; /* outbound queue meter */
 	char *queue_text;		/* outbound queue text */
-	struct User *myself;	/* it's me in the Userlist */
+	char *queue_tip;		/* outbound queue tooltip */
 	short flag_wid_state[NUM_FLAG_WIDS];
 	unsigned int c_graph:1;	/* connecting graph, is there one? */
 } restore_gui;
@@ -113,7 +121,6 @@ typedef struct session_gui
 		*window,	/* toplevel */
 		*topic_entry,
 		*note_book,
-		*main_vbox,	/* container in TOPLEVEL window */
 		*main_table,
 		*user_tree,	/* GtkTreeView */
 		*user_box,
@@ -121,6 +128,7 @@ typedef struct session_gui
 		*button_box,	/* userlist buttons' box */
 		*dialogbutton_box,
 		*topicbutton_box,
+		*meter_box,	/* all the meters inside this */
 		*lagometer,
 		*laginfo,
 		*throttlemeter,
@@ -128,19 +136,21 @@ typedef struct session_gui
 		*topic_bar,
 		*pane,
 		*menu,
-		*away_item,
-		*user_menu,
 		*bar,				/* connecting progress bar */
 		*nick_box,		/* contains label to the left of input_box */
 		*nick_label,
 		*op_xpm,			/* icon to the left of nickname */
-		*tabs_box,	/* where the tabs are */
 		*namelistinfo,	/* label above userlist */
 		*input_box,
 		*flag_wid[NUM_FLAG_WIDS],		/* channelmode buttons */
 		*limit_entry,		  /* +l */
 		*key_entry;		  /* +k */
 
+#define MENU_ID_NUM 11
+	GtkWidget *menu_item[MENU_ID_NUM+1]; /* some items we may change state of */
+
+	void *chanview;	/* chanview.h */
+
 	int bartag;		/*connecting progressbar timeout */
 
 	int pane_pos;	/*last position of the pane*/
@@ -152,3 +162,20 @@ typedef struct session_gui
 
 extern GdkPixmap *channelwin_pix;
 extern GdkPixmap *dialogwin_pix;
+
+
+#ifdef USE_GTKSPELL
+char *SPELL_ENTRY_GET_TEXT (GtkWidget *entry);
+#define SPELL_ENTRY_SET_TEXT(e,txt) gtk_text_buffer_set_text (gtk_text_view_get_buffer(GTK_TEXT_VIEW(e)),txt,-1);
+#define SPELL_ENTRY_SET_EDITABLE(e,v) gtk_text_view_set_editable(GTK_TEXT_VIEW(e), v)
+int SPELL_ENTRY_GET_POS (GtkWidget *entry);
+void SPELL_ENTRY_SET_POS (GtkWidget *entry, int pos);
+void SPELL_ENTRY_INSERT (GtkWidget *entry, const char *text, int len, int *pos);
+#else
+#define SPELL_ENTRY_GET_TEXT(e) (GTK_ENTRY(e)->text)
+#define SPELL_ENTRY_SET_TEXT(e,txt) gtk_entry_set_text(GTK_ENTRY(e),txt)
+#define SPELL_ENTRY_SET_EDITABLE(e,v) gtk_editable_set_editable(GTK_EDITABLE(e),v)
+#define SPELL_ENTRY_GET_POS(e) gtk_editable_get_position(GTK_EDITABLE(e))
+#define SPELL_ENTRY_SET_POS(e,p) gtk_editable_set_position(GTK_EDITABLE(e),p);
+#define SPELL_ENTRY_INSERT(e,t,l,p) gtk_editable_insert_text(GTK_EDITABLE(e),t,l,p)
+#endif
