@@ -185,7 +185,7 @@ url_opengui ()
 	}
 
 	urlgrabberwindow =
-		mg_create_generic_tab ("urlgrabber", _("X-Chat: URL Grabber"), FALSE,
+		mg_create_generic_tab ("UrlGrabber", _("XChat: URL Grabber"), FALSE,
 							 TRUE, url_closegui, NULL, 400, 256, &vbox, 0);
 	view = url_treeview_new (vbox);
 	g_object_set_data (G_OBJECT (urlgrabberwindow), "model",
@@ -201,8 +201,8 @@ url_opengui ()
 						 _("Clear list"), url_button_clear, 0, _("Clear"));
 	gtkutil_button (hbox, GTK_STOCK_COPY,
 						 _("Copy selected URL"), url_button_copy, view, _("Copy"));
-	gtkutil_button (hbox, GTK_STOCK_SAVE,
-						 _("Save list to a file"), url_button_save, 0, _("Save"));
+	gtkutil_button (hbox, GTK_STOCK_SAVE_AS,
+						 _("Save list to a file"), url_button_save, 0, _("Save As..."));
 
 	gtk_widget_show (urlgrabberwindow);
 
